@@ -14,10 +14,12 @@
 
 ##FIXME: Blessed structures are not formatted because we treat bless(...) as an atom
 
-use strict; use warnings FATAL => 'all'; use utf8; use 5.020;
-use feature qw(say state);
+use strict; use warnings FATAL => 'all'; use utf8; 
+use 5.020; 
+use feature qw(say state lexical_subs);
+use feature 'lexical_subs'; no warnings "experimental::lexical_subs";
 package  Data::Dumper::Interp;
-$Data::Dumper::Interp::VERSION = '3.3';
+$Data::Dumper::Interp::VERSION = '3.4';
 
 package  # newline prevents Dist::Zilla::Plugin::PkgVersion from adding $VERSION
   DB;
